Class: Google::Apis::OsconfigV1::GoogleCloudOsconfigCommonV1alphaOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb

Overview

Represents the metadata of a generic long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudOsconfigCommonV1alphaOperationMetadata

Returns a new instance of GoogleCloudOsconfigCommonV1alphaOperationMetadata.



536
537
538
# File 'lib/google/apis/osconfig_v1/classes.rb', line 536

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


500
501
502
# File 'lib/google/apis/osconfig_v1/classes.rb', line 500

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


505
506
507
# File 'lib/google/apis/osconfig_v1/classes.rb', line 505

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


510
511
512
# File 'lib/google/apis/osconfig_v1/classes.rb', line 510

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have successfully been cancelled have Operation. error value with a google.rpc.Status.code of 1, corresponding to Code. CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


518
519
520
# File 'lib/google/apis/osconfig_v1/classes.rb', line 518

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


524
525
526
# File 'lib/google/apis/osconfig_v1/classes.rb', line 524

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


529
530
531
# File 'lib/google/apis/osconfig_v1/classes.rb', line 529

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


534
535
536
# File 'lib/google/apis/osconfig_v1/classes.rb', line 534

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



541
542
543
544
545
546
547
548
549
# File 'lib/google/apis/osconfig_v1/classes.rb', line 541

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end