Class: Google::Apis::OsconfigV1::GoogleCloudOsconfigV2OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1::GoogleCloudOsconfigV2OperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb
Overview
Represents the metadata of the long-running operation.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#requested_cancellation ⇒ Boolean
(also: #requested_cancellation?)
Output only.
-
#status_message ⇒ String
Output only.
-
#target ⇒ String
Output only.
-
#verb ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudOsconfigV2OperationMetadata
constructor
A new instance of GoogleCloudOsconfigV2OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudOsconfigV2OperationMetadata
Returns a new instance of GoogleCloudOsconfigV2OperationMetadata.
700 701 702 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 700 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Output only. API version used to start the operation.
Corresponds to the JSON property apiVersion
664 665 666 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 664 def api_version @api_version end |
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
669 670 671 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 669 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
674 675 676 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 674 def end_time @end_time end |
#requested_cancellation ⇒ Boolean Also known as: requested_cancellation?
Output only. Identifies whether the user has requested cancellation of the
operation. Operations that have been cancelled successfully have Operation.
error value with a google.rpc.Status.code of 1, corresponding to Code.
CANCELLED.
Corresponds to the JSON property requestedCancellation
682 683 684 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 682 def requested_cancellation @requested_cancellation end |
#status_message ⇒ String
Output only. Human-readable status of the operation, if any.
Corresponds to the JSON property statusMessage
688 689 690 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 688 def @status_message end |
#target ⇒ String
Output only. Server-defined resource path for the target of the operation.
Corresponds to the JSON property target
693 694 695 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 693 def target @target end |
#verb ⇒ String
Output only. Name of the verb executed by the operation.
Corresponds to the JSON property verb
698 699 700 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 698 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
705 706 707 708 709 710 711 712 713 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 705 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation) @status_message = args[:status_message] if args.key?(:status_message) @target = args[:target] if args.key?(:target) @verb = args[:verb] if args.key?(:verb) end |