Class: Google::Apis::OsconfigV1::InventoryItem
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1::InventoryItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb
Overview
A single piece of inventory on a VM.
Instance Attribute Summary collapse
-
#available_package ⇒ Google::Apis::OsconfigV1::InventorySoftwarePackage
Software package information of the operating system.
-
#create_time ⇒ String
When this inventory item was first detected.
-
#id ⇒ String
Identifier for this item, unique across items for this VM.
-
#installed_package ⇒ Google::Apis::OsconfigV1::InventorySoftwarePackage
Software package information of the operating system.
-
#origin_type ⇒ String
The origin of this inventory item.
-
#type ⇒ String
The specific type of inventory, correlating to its specific details.
-
#update_time ⇒ String
When this inventory item was last modified.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InventoryItem
constructor
A new instance of InventoryItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InventoryItem
Returns a new instance of InventoryItem.
858 859 860 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 858 def initialize(**args) update!(**args) end |
Instance Attribute Details
#available_package ⇒ Google::Apis::OsconfigV1::InventorySoftwarePackage
Software package information of the operating system.
Corresponds to the JSON property availablePackage
826 827 828 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 826 def available_package @available_package end |
#create_time ⇒ String
When this inventory item was first detected.
Corresponds to the JSON property createTime
831 832 833 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 831 def create_time @create_time end |
#id ⇒ String
Identifier for this item, unique across items for this VM.
Corresponds to the JSON property id
836 837 838 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 836 def id @id end |
#installed_package ⇒ Google::Apis::OsconfigV1::InventorySoftwarePackage
Software package information of the operating system.
Corresponds to the JSON property installedPackage
841 842 843 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 841 def installed_package @installed_package end |
#origin_type ⇒ String
The origin of this inventory item.
Corresponds to the JSON property originType
846 847 848 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 846 def origin_type @origin_type end |
#type ⇒ String
The specific type of inventory, correlating to its specific details.
Corresponds to the JSON property type
851 852 853 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 851 def type @type end |
#update_time ⇒ String
When this inventory item was last modified.
Corresponds to the JSON property updateTime
856 857 858 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 856 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
863 864 865 866 867 868 869 870 871 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 863 def update!(**args) @available_package = args[:available_package] if args.key?(:available_package) @create_time = args[:create_time] if args.key?(:create_time) @id = args[:id] if args.key?(:id) @installed_package = args[:installed_package] if args.key?(:installed_package) @origin_type = args[:origin_type] if args.key?(:origin_type) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |