Class: Google::Apis::OsconfigV1::InventorySoftwarePackage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb

Overview

Software package information of the operating system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InventorySoftwarePackage

Returns a new instance of InventorySoftwarePackage.



820
821
822
# File 'lib/google/apis/osconfig_v1/classes.rb', line 820

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apt_packageGoogle::Apis::OsconfigV1::InventoryVersionedPackage

Information related to the a standard versioned package. This includes package info for APT, Yum, Zypper, and Googet package managers. Corresponds to the JSON property aptPackage



767
768
769
# File 'lib/google/apis/osconfig_v1/classes.rb', line 767

def apt_package
  @apt_package
end

#cos_packageGoogle::Apis::OsconfigV1::InventoryVersionedPackage

Information related to the a standard versioned package. This includes package info for APT, Yum, Zypper, and Googet package managers. Corresponds to the JSON property cosPackage



773
774
775
# File 'lib/google/apis/osconfig_v1/classes.rb', line 773

def cos_package
  @cos_package
end

#googet_packageGoogle::Apis::OsconfigV1::InventoryVersionedPackage

Information related to the a standard versioned package. This includes package info for APT, Yum, Zypper, and Googet package managers. Corresponds to the JSON property googetPackage



779
780
781
# File 'lib/google/apis/osconfig_v1/classes.rb', line 779

def googet_package
  @googet_package
end

#qfe_packageGoogle::Apis::OsconfigV1::InventoryWindowsQuickFixEngineeringPackage

Information related to a Quick Fix Engineering package. Fields are taken from Windows QuickFixEngineering Interface and match the source names: https://docs. microsoft.com/en-us/windows/win32/cimwin32prov/win32-quickfixengineering Corresponds to the JSON property qfePackage



786
787
788
# File 'lib/google/apis/osconfig_v1/classes.rb', line 786

def qfe_package
  @qfe_package
end

#windows_applicationGoogle::Apis::OsconfigV1::InventoryWindowsApplication

Contains information about a Windows application that is retrieved from the Windows Registry. For more information about these fields, see: https://docs. microsoft.com/en-us/windows/win32/msi/uninstall-registry-key Corresponds to the JSON property windowsApplication



793
794
795
# File 'lib/google/apis/osconfig_v1/classes.rb', line 793

def windows_application
  @windows_application
end

#wua_packageGoogle::Apis::OsconfigV1::InventoryWindowsUpdatePackage

Details related to a Windows Update package. Field data and names are taken from Windows Update API IUpdate Interface: https://docs.microsoft.com/en-us/ windows/win32/api/_wua/ Descriptive fields like title, and description are localized based on the locale of the VM being updated. Corresponds to the JSON property wuaPackage



801
802
803
# File 'lib/google/apis/osconfig_v1/classes.rb', line 801

def wua_package
  @wua_package
end

#yum_packageGoogle::Apis::OsconfigV1::InventoryVersionedPackage

Information related to the a standard versioned package. This includes package info for APT, Yum, Zypper, and Googet package managers. Corresponds to the JSON property yumPackage



807
808
809
# File 'lib/google/apis/osconfig_v1/classes.rb', line 807

def yum_package
  @yum_package
end

#zypper_packageGoogle::Apis::OsconfigV1::InventoryVersionedPackage

Information related to the a standard versioned package. This includes package info for APT, Yum, Zypper, and Googet package managers. Corresponds to the JSON property zypperPackage



813
814
815
# File 'lib/google/apis/osconfig_v1/classes.rb', line 813

def zypper_package
  @zypper_package
end

#zypper_patchGoogle::Apis::OsconfigV1::InventoryZypperPatch

Details related to a Zypper Patch. Corresponds to the JSON property zypperPatch



818
819
820
# File 'lib/google/apis/osconfig_v1/classes.rb', line 818

def zypper_patch
  @zypper_patch
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



825
826
827
828
829
830
831
832
833
834
835
# File 'lib/google/apis/osconfig_v1/classes.rb', line 825

def update!(**args)
  @apt_package = args[:apt_package] if args.key?(:apt_package)
  @cos_package = args[:cos_package] if args.key?(:cos_package)
  @googet_package = args[:googet_package] if args.key?(:googet_package)
  @qfe_package = args[:qfe_package] if args.key?(:qfe_package)
  @windows_application = args[:windows_application] if args.key?(:windows_application)
  @wua_package = args[:wua_package] if args.key?(:wua_package)
  @yum_package = args[:yum_package] if args.key?(:yum_package)
  @zypper_package = args[:zypper_package] if args.key?(:zypper_package)
  @zypper_patch = args[:zypper_patch] if args.key?(:zypper_patch)
end