Class: Google::Apis::OsconfigV1::InventoryWindowsUpdatePackage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb

Overview

Details related to a Windows Update package. Field data and names are taken from Windows Update API IUpdate Interface: https://docs.microsoft.com/en-us/ windows/win32/api/_wua/ Descriptive fields like title, and description are localized based on the locale of the VM being updated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InventoryWindowsUpdatePackage

Returns a new instance of InventoryWindowsUpdatePackage.



1014
1015
1016
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1014

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoriesArray<Google::Apis::OsconfigV1::InventoryWindowsUpdatePackageWindowsUpdateCategory>

The categories that are associated with this update package. Corresponds to the JSON property categories



971
972
973
# File 'lib/google/apis/osconfig_v1/classes.rb', line 971

def categories
  @categories
end

#descriptionString

The localized description of the update package. Corresponds to the JSON property description

Returns:

  • (String)


976
977
978
# File 'lib/google/apis/osconfig_v1/classes.rb', line 976

def description
  @description
end

#kb_article_idsArray<String>

A collection of Microsoft Knowledge Base article IDs that are associated with the update package. Corresponds to the JSON property kbArticleIds

Returns:

  • (Array<String>)


982
983
984
# File 'lib/google/apis/osconfig_v1/classes.rb', line 982

def kb_article_ids
  @kb_article_ids
end

#last_deployment_change_timeString

The last published date of the update, in (UTC) date and time. Corresponds to the JSON property lastDeploymentChangeTime

Returns:

  • (String)


987
988
989
# File 'lib/google/apis/osconfig_v1/classes.rb', line 987

def last_deployment_change_time
  @last_deployment_change_time
end

#more_info_urlsArray<String>

A collection of URLs that provide more information about the update package. Corresponds to the JSON property moreInfoUrls

Returns:

  • (Array<String>)


992
993
994
# File 'lib/google/apis/osconfig_v1/classes.rb', line 992

def more_info_urls
  @more_info_urls
end

#revision_numberFixnum

The revision number of this update package. Corresponds to the JSON property revisionNumber

Returns:

  • (Fixnum)


997
998
999
# File 'lib/google/apis/osconfig_v1/classes.rb', line 997

def revision_number
  @revision_number
end

#support_urlString

A hyperlink to the language-specific support information for the update. Corresponds to the JSON property supportUrl

Returns:

  • (String)


1002
1003
1004
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1002

def support_url
  @support_url
end

#titleString

The localized title of the update package. Corresponds to the JSON property title

Returns:

  • (String)


1007
1008
1009
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1007

def title
  @title
end

#update_idString

Gets the identifier of an update package. Stays the same across revisions. Corresponds to the JSON property updateId

Returns:

  • (String)


1012
1013
1014
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1012

def update_id
  @update_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1019

def update!(**args)
  @categories = args[:categories] if args.key?(:categories)
  @description = args[:description] if args.key?(:description)
  @kb_article_ids = args[:kb_article_ids] if args.key?(:kb_article_ids)
  @last_deployment_change_time = args[:last_deployment_change_time] if args.key?(:last_deployment_change_time)
  @more_info_urls = args[:more_info_urls] if args.key?(:more_info_urls)
  @revision_number = args[:revision_number] if args.key?(:revision_number)
  @support_url = args[:support_url] if args.key?(:support_url)
  @title = args[:title] if args.key?(:title)
  @update_id = args[:update_id] if args.key?(:update_id)
end