Class: Google::Apis::OsconfigV1::ListInventoriesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb

Overview

A response message for listing inventory data for all VMs in a specified location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInventoriesResponse

Returns a new instance of ListInventoriesResponse.



1286
1287
1288
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1286

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inventoriesArray<Google::Apis::OsconfigV1::Inventory>

List of inventory objects. Corresponds to the JSON property inventories



1279
1280
1281
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1279

def inventories
  @inventories
end

#next_page_tokenString

The pagination token to retrieve the next page of inventory objects. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1284
1285
1286
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1284

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1291
1292
1293
1294
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1291

def update!(**args)
  @inventories = args[:inventories] if args.key?(:inventories)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end