Class: Google::Apis::OsconfigV1::ListOsPolicyAssignmentReportsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb

Overview

A response message for listing OS Policy assignment reports including the page of results and page token.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListOsPolicyAssignmentReportsResponse

Returns a new instance of ListOsPolicyAssignmentReportsResponse.



1313
1314
1315
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1313

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The pagination token to retrieve the next page of OS policy assignment report objects. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1306
1307
1308
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1306

def next_page_token
  @next_page_token
end

#os_policy_assignment_reportsArray<Google::Apis::OsconfigV1::OsPolicyAssignmentReport>

List of OS policy assignment reports. Corresponds to the JSON property osPolicyAssignmentReports



1311
1312
1313
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1311

def os_policy_assignment_reports
  @os_policy_assignment_reports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1318
1319
1320
1321
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1318

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @os_policy_assignment_reports = args[:os_policy_assignment_reports] if args.key?(:os_policy_assignment_reports)
end