Class: Google::Apis::OsconfigV1::ListOsPolicyAssignmentsResponse
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1::ListOsPolicyAssignmentsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb
Overview
A response message for listing all assignments under given parent.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The pagination token to retrieve the next page of OS policy assignments.
-
#os_policy_assignments ⇒ Array<Google::Apis::OsconfigV1::OsPolicyAssignment>
The list of assignments Corresponds to the JSON property
osPolicyAssignments.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListOsPolicyAssignmentsResponse
constructor
A new instance of ListOsPolicyAssignmentsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListOsPolicyAssignmentsResponse
Returns a new instance of ListOsPolicyAssignmentsResponse.
1364 1365 1366 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1364 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The pagination token to retrieve the next page of OS policy assignments.
Corresponds to the JSON property nextPageToken
1357 1358 1359 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1357 def next_page_token @next_page_token end |
#os_policy_assignments ⇒ Array<Google::Apis::OsconfigV1::OsPolicyAssignment>
The list of assignments
Corresponds to the JSON property osPolicyAssignments
1362 1363 1364 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1362 def os_policy_assignments @os_policy_assignments end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1369 1370 1371 1372 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1369 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @os_policy_assignments = args[:os_policy_assignments] if args.key?(:os_policy_assignments) end |