Class: Google::Apis::OsconfigV1::OSConfigService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::OsconfigV1::OSConfigService
- Defined in:
- lib/google/apis/osconfig_v1/service.rb
Overview
OS Config API
OS management tools that can be used for patch management, patch compliance, and configuration management on VM instances.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://osconfig.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#cancel_patch_job(name, cancel_patch_job_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::PatchJob
Cancel a patch job.
-
#cancel_project_location_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_os_policy_assignment(parent, os_policy_assignment_object = nil, os_policy_assignment_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::Operation
Create an OS policy assignment.
-
#create_project_patch_deployment(parent, patch_deployment_object = nil, patch_deployment_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::PatchDeployment
Create an OS Config patch deployment.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::Empty
Deletes a long-running operation.
-
#delete_project_location_os_policy_assignment(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::Operation
Delete the OS policy assignment.
-
#delete_project_patch_deployment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::Empty
Delete an OS Config patch deployment.
-
#execute_patch_job(parent, execute_patch_job_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::PatchJob
Patch VM instances by creating and running a patch job.
-
#get_project_location_global_project_feature_settings(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::ProjectFeatureSettings
GetProjectFeatureSettings returns the VM Manager feature settings for a project.
-
#get_project_location_instance_inventory(name, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::Inventory
Get inventory data for the specified VM instance.
-
#get_project_location_instance_os_policy_assignment_report(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::OsPolicyAssignmentReport
Get the OS policy assignment report for the specified Compute Engine VM instance.
-
#get_project_location_instance_vulnerability_report(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::VulnerabilityReport
Gets the vulnerability report for the specified VM instance.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_os_policy_assignment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::OsPolicyAssignment
Retrieve an existing OS policy assignment.
-
#get_project_location_os_policy_assignment_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::Operation
Gets the latest state of a long-running operation.
-
#get_project_patch_deployment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::PatchDeployment
Get an OS Config patch deployment.
-
#get_project_patch_job(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::PatchJob
Get the patch job.
-
#initialize ⇒ OSConfigService
constructor
A new instance of OSConfigService.
-
#list_project_location_instance_inventories(parent, filter: nil, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::ListInventoriesResponse
List inventory data for all VM instances in the specified zone.
-
#list_project_location_instance_os_policy_assignment_reports(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::ListOsPolicyAssignmentReportsResponse
List OS policy assignment reports for all Compute Engine VM instances in the specified zone.
-
#list_project_location_instance_vulnerability_reports(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::ListVulnerabilityReportsResponse
List vulnerability reports for all VM instances in the specified zone.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_os_policy_assignment_revisions(name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::ListOsPolicyAssignmentRevisionsResponse
List the OS policy assignment revisions for a given OS policy assignment.
-
#list_project_location_os_policy_assignments(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::ListOsPolicyAssignmentsResponse
List the OS policy assignments under the parent resource.
-
#list_project_patch_deployments(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::ListPatchDeploymentsResponse
Get a page of OS Config patch deployments.
-
#list_project_patch_job_instance_details(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::ListPatchJobInstanceDetailsResponse
Get a list of instance details for a given patch job.
-
#list_project_patch_jobs(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::ListPatchJobsResponse
Get a list of patch jobs.
-
#patch_project_location_os_policy_assignment(name, os_policy_assignment_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::Operation
Update an existing OS policy assignment.
-
#patch_project_patch_deployment(name, patch_deployment_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::PatchDeployment
Update an OS Config patch deployment.
-
#pause_patch_deployment(name, pause_patch_deployment_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::PatchDeployment
Change state of patch deployment to "PAUSED".
-
#resume_patch_deployment(name, resume_patch_deployment_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::PatchDeployment
Change state of patch deployment back to "ACTIVE".
-
#update_project_location_global_project_feature_settings(name, project_feature_settings_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::ProjectFeatureSettings
UpdateProjectFeatureSettings sets the VM Manager features for a project.
Constructor Details
#initialize ⇒ OSConfigService
Returns a new instance of OSConfigService.
48 49 50 51 52 53 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-osconfig_v1', client_version: Google::Apis::OsconfigV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
826 827 828 829 830 831 832 833 834 835 836 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 826 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::OsconfigV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::OsconfigV1::Empty::Representation command.response_class = Google::Apis::OsconfigV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#cancel_patch_job(name, cancel_patch_job_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::PatchJob
Cancel a patch job. The patch job must be active. Canceled patch jobs cannot be restarted.
1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 1140 def cancel_patch_job(name, cancel_patch_job_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::OsconfigV1::CancelPatchJobRequest::Representation command.request_object = cancel_patch_job_request_object command.response_representation = Google::Apis::OsconfigV1::PatchJob::Representation command.response_class = Google::Apis::OsconfigV1::PatchJob command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#cancel_project_location_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 418 def cancel_project_location_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::OsconfigV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::OsconfigV1::Empty::Representation command.response_class = Google::Apis::OsconfigV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_os_policy_assignment(parent, os_policy_assignment_object = nil, os_policy_assignment_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::Operation
Create an OS policy assignment. This method also creates the first revision of the OS policy assignment. This method returns a long running operation (LRO) that contains the rollout details. The rollout can be cancelled by cancelling the LRO. For more information, see Method: projects.locations. osPolicyAssignments.operations.cancel.
579 580 581 582 583 584 585 586 587 588 589 590 591 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 579 def create_project_location_os_policy_assignment(parent, os_policy_assignment_object = nil, os_policy_assignment_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/osPolicyAssignments', ) command.request_representation = Google::Apis::OsconfigV1::OsPolicyAssignment::Representation command.request_object = os_policy_assignment_object command.response_representation = Google::Apis::OsconfigV1::Operation::Representation command.response_class = Google::Apis::OsconfigV1::Operation command.params['parent'] = parent unless parent.nil? command.query['osPolicyAssignmentId'] = os_policy_assignment_id unless os_policy_assignment_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_patch_deployment(parent, patch_deployment_object = nil, patch_deployment_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::PatchDeployment
Create an OS Config patch deployment.
896 897 898 899 900 901 902 903 904 905 906 907 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 896 def create_project_patch_deployment(parent, patch_deployment_object = nil, patch_deployment_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/patchDeployments', ) command.request_representation = Google::Apis::OsconfigV1::PatchDeployment::Representation command.request_object = patch_deployment_object command.response_representation = Google::Apis::OsconfigV1::PatchDeployment::Representation command.response_class = Google::Apis::OsconfigV1::PatchDeployment command.params['parent'] = parent unless parent.nil? command.query['patchDeploymentId'] = patch_deployment_id unless patch_deployment_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
453 454 455 456 457 458 459 460 461 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 453 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::OsconfigV1::Empty::Representation command.response_class = Google::Apis::OsconfigV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_os_policy_assignment(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::Operation
Delete the OS policy assignment. This method creates a new revision of the OS policy assignment. This method returns a long running operation (LRO) that contains the rollout details. The rollout can be cancelled by cancelling the LRO. If the LRO completes and is not cancelled, all revisions associated with the OS policy assignment are deleted. For more information, see Method: projects.locations.osPolicyAssignments.operations.cancel.
624 625 626 627 628 629 630 631 632 633 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 624 def delete_project_location_os_policy_assignment(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::OsconfigV1::Operation::Representation command.response_class = Google::Apis::OsconfigV1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_patch_deployment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::Empty
Delete an OS Config patch deployment.
930 931 932 933 934 935 936 937 938 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 930 def delete_project_patch_deployment(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::OsconfigV1::Empty::Representation command.response_class = Google::Apis::OsconfigV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#execute_patch_job(parent, execute_patch_job_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::PatchJob
Patch VM instances by creating and running a patch job.
1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 1173 def execute_patch_job(parent, execute_patch_job_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/patchJobs:execute', ) command.request_representation = Google::Apis::OsconfigV1::ExecutePatchJobRequest::Representation command.request_object = execute_patch_job_request_object command.response_representation = Google::Apis::OsconfigV1::PatchJob::Representation command.response_class = Google::Apis::OsconfigV1::PatchJob command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_global_project_feature_settings(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::ProjectFeatureSettings
GetProjectFeatureSettings returns the VM Manager feature settings for a project.
77 78 79 80 81 82 83 84 85 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 77 def get_project_location_global_project_feature_settings(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::OsconfigV1::ProjectFeatureSettings::Representation command.response_class = Google::Apis::OsconfigV1::ProjectFeatureSettings command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_instance_inventory(name, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::Inventory
Get inventory data for the specified VM instance. If the VM has no associated
inventory, the message NOT_FOUND is returned.
152 153 154 155 156 157 158 159 160 161 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 152 def get_project_location_instance_inventory(name, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::OsconfigV1::Inventory::Representation command.response_class = Google::Apis::OsconfigV1::Inventory command.params['name'] = name unless name.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_instance_os_policy_assignment_report(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::OsPolicyAssignmentReport
Get the OS policy assignment report for the specified Compute Engine VM instance.
236 237 238 239 240 241 242 243 244 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 236 def get_project_location_instance_os_policy_assignment_report(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::OsconfigV1::OsPolicyAssignmentReport::Representation command.response_class = Google::Apis::OsconfigV1::OsPolicyAssignmentReport command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_instance_vulnerability_report(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::VulnerabilityReport
Gets the vulnerability report for the specified VM instance. Only VMs with inventory data have vulnerability reports associated with them.
328 329 330 331 332 333 334 335 336 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 328 def get_project_location_instance_vulnerability_report(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::OsconfigV1::VulnerabilityReport::Representation command.response_class = Google::Apis::OsconfigV1::VulnerabilityReport command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
484 485 486 487 488 489 490 491 492 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 484 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::OsconfigV1::Operation::Representation command.response_class = Google::Apis::OsconfigV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_os_policy_assignment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::OsPolicyAssignment
Retrieve an existing OS policy assignment. This method always returns the
latest revision. In order to retrieve a previous revision of the assignment,
also provide the revision ID in the name parameter.
659 660 661 662 663 664 665 666 667 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 659 def get_project_location_os_policy_assignment(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::OsconfigV1::OsPolicyAssignment::Representation command.response_class = Google::Apis::OsconfigV1::OsPolicyAssignment command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_os_policy_assignment_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
859 860 861 862 863 864 865 866 867 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 859 def get_project_location_os_policy_assignment_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::OsconfigV1::Operation::Representation command.response_class = Google::Apis::OsconfigV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_patch_deployment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::PatchDeployment
Get an OS Config patch deployment.
961 962 963 964 965 966 967 968 969 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 961 def get_project_patch_deployment(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::OsconfigV1::PatchDeployment::Representation command.response_class = Google::Apis::OsconfigV1::PatchDeployment command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_patch_job(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::PatchJob
Get the patch job. This can be used to track the progress of an ongoing patch job or review the details of completed jobs.
1206 1207 1208 1209 1210 1211 1212 1213 1214 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 1206 def get_project_patch_job(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::OsconfigV1::PatchJob::Representation command.response_class = Google::Apis::OsconfigV1::PatchJob command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_instance_inventories(parent, filter: nil, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::ListInventoriesResponse
List inventory data for all VM instances in the specified zone.
196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 196 def list_project_location_instance_inventories(parent, filter: nil, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/inventories', ) command.response_representation = Google::Apis::OsconfigV1::ListInventoriesResponse::Representation command.response_class = Google::Apis::OsconfigV1::ListInventoriesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_instance_os_policy_assignment_reports(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::ListOsPolicyAssignmentReportsResponse
List OS policy assignment reports for all Compute Engine VM instances in the specified zone.
290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 290 def list_project_location_instance_os_policy_assignment_reports(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/reports', ) command.response_representation = Google::Apis::OsconfigV1::ListOsPolicyAssignmentReportsResponse::Representation command.response_class = Google::Apis::OsconfigV1::ListOsPolicyAssignmentReportsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_instance_vulnerability_reports(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::ListVulnerabilityReportsResponse
List vulnerability reports for all VM instances in the specified zone.
377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 377 def list_project_location_instance_vulnerability_reports(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/vulnerabilityReports', ) command.response_representation = Google::Apis::OsconfigV1::ListVulnerabilityReportsResponse::Representation command.response_class = Google::Apis::OsconfigV1::ListVulnerabilityReportsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
529 530 531 532 533 534 535 536 537 538 539 540 541 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 529 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::OsconfigV1::ListOperationsResponse::Representation command.response_class = Google::Apis::OsconfigV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_os_policy_assignment_revisions(name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::ListOsPolicyAssignmentRevisionsResponse
List the OS policy assignment revisions for a given OS policy assignment.
733 734 735 736 737 738 739 740 741 742 743 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 733 def list_project_location_os_policy_assignment_revisions(name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}:listRevisions', ) command.response_representation = Google::Apis::OsconfigV1::ListOsPolicyAssignmentRevisionsResponse::Representation command.response_class = Google::Apis::OsconfigV1::ListOsPolicyAssignmentRevisionsResponse command.params['name'] = name unless name.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_os_policy_assignments(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::ListOsPolicyAssignmentsResponse
List the OS policy assignments under the parent resource. For each OS policy assignment, the latest revision is returned.
695 696 697 698 699 700 701 702 703 704 705 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 695 def list_project_location_os_policy_assignments(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/osPolicyAssignments', ) command.response_representation = Google::Apis::OsconfigV1::ListOsPolicyAssignmentsResponse::Representation command.response_class = Google::Apis::OsconfigV1::ListOsPolicyAssignmentsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_patch_deployments(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::ListPatchDeploymentsResponse
Get a page of OS Config patch deployments.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 996 def list_project_patch_deployments(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/patchDeployments', ) command.response_representation = Google::Apis::OsconfigV1::ListPatchDeploymentsResponse::Representation command.response_class = Google::Apis::OsconfigV1::ListPatchDeploymentsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_patch_job_instance_details(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::ListPatchJobInstanceDetailsResponse
Get a list of instance details for a given patch job.
1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 1287 def list_project_patch_job_instance_details(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/instanceDetails', ) command.response_representation = Google::Apis::OsconfigV1::ListPatchJobInstanceDetailsResponse::Representation command.response_class = Google::Apis::OsconfigV1::ListPatchJobInstanceDetailsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_patch_jobs(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::ListPatchJobsResponse
Get a list of patch jobs.
1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 1245 def list_project_patch_jobs(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/patchJobs', ) command.response_representation = Google::Apis::OsconfigV1::ListPatchJobsResponse::Representation command.response_class = Google::Apis::OsconfigV1::ListPatchJobsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_os_policy_assignment(name, os_policy_assignment_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::Operation
Update an existing OS policy assignment. This method creates a new revision of the OS policy assignment. This method returns a long running operation (LRO) that contains the rollout details. The rollout can be cancelled by cancelling the LRO. For more information, see Method: projects.locations. osPolicyAssignments.operations.cancel.
783 784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 783 def patch_project_location_os_policy_assignment(name, os_policy_assignment_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::OsconfigV1::OsPolicyAssignment::Representation command.request_object = os_policy_assignment_object command.response_representation = Google::Apis::OsconfigV1::Operation::Representation command.response_class = Google::Apis::OsconfigV1::Operation command.params['name'] = name unless name.nil? command.query['allowMissing'] = allow_missing unless allow_missing.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_patch_deployment(name, patch_deployment_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::PatchDeployment
Update an OS Config patch deployment.
1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 1035 def patch_project_patch_deployment(name, patch_deployment_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::OsconfigV1::PatchDeployment::Representation command.request_object = patch_deployment_object command.response_representation = Google::Apis::OsconfigV1::PatchDeployment::Representation command.response_class = Google::Apis::OsconfigV1::PatchDeployment command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#pause_patch_deployment(name, pause_patch_deployment_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::PatchDeployment
Change state of patch deployment to "PAUSED". Patch deployment in paused state doesn't generate patch jobs.
1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 1071 def pause_patch_deployment(name, pause_patch_deployment_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:pause', ) command.request_representation = Google::Apis::OsconfigV1::PausePatchDeploymentRequest::Representation command.request_object = pause_patch_deployment_request_object command.response_representation = Google::Apis::OsconfigV1::PatchDeployment::Representation command.response_class = Google::Apis::OsconfigV1::PatchDeployment command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#resume_patch_deployment(name, resume_patch_deployment_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::PatchDeployment
Change state of patch deployment back to "ACTIVE". Patch deployment in active state continues to generate patch jobs.
1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 1106 def resume_patch_deployment(name, resume_patch_deployment_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:resume', ) command.request_representation = Google::Apis::OsconfigV1::ResumePatchDeploymentRequest::Representation command.request_object = resume_patch_deployment_request_object command.response_representation = Google::Apis::OsconfigV1::PatchDeployment::Representation command.response_class = Google::Apis::OsconfigV1::PatchDeployment command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_project_location_global_project_feature_settings(name, project_feature_settings_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV1::ProjectFeatureSettings
UpdateProjectFeatureSettings sets the VM Manager features for a project.
112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/google/apis/osconfig_v1/service.rb', line 112 def update_project_location_global_project_feature_settings(name, project_feature_settings_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::OsconfigV1::ProjectFeatureSettings::Representation command.request_object = project_feature_settings_object command.response_representation = Google::Apis::OsconfigV1::ProjectFeatureSettings::Representation command.response_class = Google::Apis::OsconfigV1::ProjectFeatureSettings command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |