Class: Google::Apis::OsconfigV1::OsPolicyResource
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1::OsPolicyResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb
Overview
An OS policy resource is used to define the desired state configuration and provides a specific functionality like installing/removing packages, executing a script etc. The system ensures that resources are always in their desired state by taking necessary actions if they have drifted from their desired state.
Instance Attribute Summary collapse
-
#exec ⇒ Google::Apis::OsconfigV1::OsPolicyResourceExecResource
A resource that allows executing scripts on the VM.
-
#file ⇒ Google::Apis::OsconfigV1::OsPolicyResourceFileResource
A resource that manages the state of a file.
-
#id ⇒ String
Required.
-
#pkg ⇒ Google::Apis::OsconfigV1::OsPolicyResourcePackageResource
A resource that manages a system package.
-
#repository ⇒ Google::Apis::OsconfigV1::OsPolicyResourceRepositoryResource
A resource that manages a package repository.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OsPolicyResource
constructor
A new instance of OsPolicyResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OsPolicyResource
Returns a new instance of OsPolicyResource.
2195 2196 2197 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 2195 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exec ⇒ Google::Apis::OsconfigV1::OsPolicyResourceExecResource
A resource that allows executing scripts on the VM. The ExecResource has 2
stages: validate and enforce and both stages accept a script as an
argument to execute. When the ExecResource is applied by the agent, it first
executes the script in the validate stage. The validate stage can signal
that the ExecResource is already in the desired state by returning an exit
code of 100. If the ExecResource is not in the desired state, it should
return an exit code of 101. Any other exit code returned by this stage is
considered an error. If the ExecResource is not in the desired state based
on the exit code from the validate stage, the agent proceeds to execute the
script from the enforce stage. If the ExecResource is already in the
desired state, the enforce stage will not be run. Similar to validate
stage, the enforce stage should return an exit code of 100 to indicate
that the resource in now in its desired state. Any other exit code is
considered an error. NOTE: An exit code of 100 was chosen over 0 (and 101
vs 1) to have an explicit indicator of in desired state, not in desired
state and errors. Because, for example, Powershell will always return an exit
code of 0 unless an exit statement is provided in the script. So, for
reasons of consistency and being explicit, exit codes 100 and 101 were
chosen.
Corresponds to the JSON property exec
2170 2171 2172 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 2170 def exec @exec end |
#file ⇒ Google::Apis::OsconfigV1::OsPolicyResourceFileResource
A resource that manages the state of a file.
Corresponds to the JSON property file
2175 2176 2177 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 2175 def file @file end |
#id ⇒ String
Required. The id of the resource with the following restrictions: * Must
contain only lowercase letters, numbers, and hyphens. * Must start with a
letter. * Must be between 1-63 characters. * Must end with a number or a
letter. * Must be unique within the OS policy.
Corresponds to the JSON property id
2183 2184 2185 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 2183 def id @id end |
#pkg ⇒ Google::Apis::OsconfigV1::OsPolicyResourcePackageResource
A resource that manages a system package.
Corresponds to the JSON property pkg
2188 2189 2190 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 2188 def pkg @pkg end |
#repository ⇒ Google::Apis::OsconfigV1::OsPolicyResourceRepositoryResource
A resource that manages a package repository.
Corresponds to the JSON property repository
2193 2194 2195 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 2193 def repository @repository end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2200 2201 2202 2203 2204 2205 2206 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 2200 def update!(**args) @exec = args[:exec] if args.key?(:exec) @file = args[:file] if args.key?(:file) @id = args[:id] if args.key?(:id) @pkg = args[:pkg] if args.key?(:pkg) @repository = args[:repository] if args.key?(:repository) end |