Class: Google::Apis::OsconfigV1::OsPolicyResourceRepositoryResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb

Overview

A resource that manages a package repository.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OsPolicyResourceRepositoryResource

Returns a new instance of OsPolicyResourceRepositoryResource.



2737
2738
2739
# File 'lib/google/apis/osconfig_v1/classes.rb', line 2737

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aptGoogle::Apis::OsconfigV1::OsPolicyResourceRepositoryResourceAptRepository

Represents a single apt package repository. These will be added to a repo file that will be managed at /etc/apt/sources.list.d/google_osconfig.list. Corresponds to the JSON property apt



2717
2718
2719
# File 'lib/google/apis/osconfig_v1/classes.rb', line 2717

def apt
  @apt
end

#gooGoogle::Apis::OsconfigV1::OsPolicyResourceRepositoryResourceGooRepository

Represents a Goo package repository. These are added to a repo file that is managed at C:/ProgramData/GooGet/repos/google_osconfig.repo. Corresponds to the JSON property goo



2723
2724
2725
# File 'lib/google/apis/osconfig_v1/classes.rb', line 2723

def goo
  @goo
end

#yumGoogle::Apis::OsconfigV1::OsPolicyResourceRepositoryResourceYumRepository

Represents a single yum package repository. These are added to a repo file that is managed at /etc/yum.repos.d/google_osconfig.repo. Corresponds to the JSON property yum



2729
2730
2731
# File 'lib/google/apis/osconfig_v1/classes.rb', line 2729

def yum
  @yum
end

#zypperGoogle::Apis::OsconfigV1::OsPolicyResourceRepositoryResourceZypperRepository

Represents a single zypper package repository. These are added to a repo file that is managed at /etc/zypp/repos.d/google_osconfig.repo. Corresponds to the JSON property zypper



2735
2736
2737
# File 'lib/google/apis/osconfig_v1/classes.rb', line 2735

def zypper
  @zypper
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2742
2743
2744
2745
2746
2747
# File 'lib/google/apis/osconfig_v1/classes.rb', line 2742

def update!(**args)
  @apt = args[:apt] if args.key?(:apt)
  @goo = args[:goo] if args.key?(:goo)
  @yum = args[:yum] if args.key?(:yum)
  @zypper = args[:zypper] if args.key?(:zypper)
end