Class: Google::Apis::OsconfigV1::PatchJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb

Overview

A high level representation of a patch job that is either in progress or has completed. Instance details are not included in the job. To paginate through instance details, use ListPatchJobInstanceDetails. For more information about patch jobs, see Creating patch jobs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PatchJob

Returns a new instance of PatchJob.



3139
3140
3141
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3139

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Time this patch job was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3056
3057
3058
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3056

def create_time
  @create_time
end

#descriptionString

Description of the patch job. Length of the description is limited to 1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


3062
3063
3064
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3062

def description
  @description
end

#display_nameString

Display name for this patch job. This is not a unique identifier. Corresponds to the JSON property displayName

Returns:

  • (String)


3067
3068
3069
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3067

def display_name
  @display_name
end

#dry_runBoolean Also known as: dry_run?

If this patch job is a dry run, the agent reports that it has finished without running any updates on the VM instance. Corresponds to the JSON property dryRun

Returns:

  • (Boolean)


3073
3074
3075
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3073

def dry_run
  @dry_run
end

#durationString

Duration of the patch job. After the duration ends, the patch job times out. Corresponds to the JSON property duration

Returns:

  • (String)


3079
3080
3081
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3079

def duration
  @duration
end

#error_messageString

If this patch job failed, this message provides information about the failure. Corresponds to the JSON property errorMessage

Returns:

  • (String)


3084
3085
3086
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3084

def error_message
  @error_message
end

#instance_details_summaryGoogle::Apis::OsconfigV1::PatchJobInstanceDetailsSummary

A summary of the current patch state across all instances that this patch job affects. Contains counts of instances in different states. These states map to InstancePatchState. List patch job instance details to see the specific states of each instance. Corresponds to the JSON property instanceDetailsSummary



3092
3093
3094
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3092

def instance_details_summary
  @instance_details_summary
end

#instance_filterGoogle::Apis::OsconfigV1::PatchInstanceFilter

A filter to target VM instances for patching. The targeted VMs must meet all criteria specified. So if both labels and zones are specified, the patch job targets only VMs with those labels and in those zones. Corresponds to the JSON property instanceFilter



3099
3100
3101
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3099

def instance_filter
  @instance_filter
end

#nameString

Unique identifier for this patch job in the form projects/*/patchJobs/* Corresponds to the JSON property name

Returns:

  • (String)


3104
3105
3106
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3104

def name
  @name
end

#patch_configGoogle::Apis::OsconfigV1::PatchConfig

Patch configuration specifications. Contains details on how to apply the patch( es) to a VM instance. Corresponds to the JSON property patchConfig



3110
3111
3112
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3110

def patch_config
  @patch_config
end

#patch_deploymentString

Output only. Name of the patch deployment that created this patch job. Corresponds to the JSON property patchDeployment

Returns:

  • (String)


3115
3116
3117
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3115

def patch_deployment
  @patch_deployment
end

#percent_completeFloat

Reflects the overall progress of the patch job in the range of 0.0 being no progress to 100.0 being complete. Corresponds to the JSON property percentComplete

Returns:

  • (Float)


3121
3122
3123
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3121

def percent_complete
  @percent_complete
end

#rolloutGoogle::Apis::OsconfigV1::PatchRollout

Patch rollout configuration specifications. Contains details on the concurrency control when applying patch(es) to all targeted VMs. Corresponds to the JSON property rollout



3127
3128
3129
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3127

def rollout
  @rollout
end

#stateString

The current state of the PatchJob. Corresponds to the JSON property state

Returns:

  • (String)


3132
3133
3134
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3132

def state
  @state
end

#update_timeString

Last time this patch job was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3137
3138
3139
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3137

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3144
3145
3146
3147
3148
3149
3150
3151
3152
3153
3154
3155
3156
3157
3158
3159
3160
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3144

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @dry_run = args[:dry_run] if args.key?(:dry_run)
  @duration = args[:duration] if args.key?(:duration)
  @error_message = args[:error_message] if args.key?(:error_message)
  @instance_details_summary = args[:instance_details_summary] if args.key?(:instance_details_summary)
  @instance_filter = args[:instance_filter] if args.key?(:instance_filter)
  @name = args[:name] if args.key?(:name)
  @patch_config = args[:patch_config] if args.key?(:patch_config)
  @patch_deployment = args[:patch_deployment] if args.key?(:patch_deployment)
  @percent_complete = args[:percent_complete] if args.key?(:percent_complete)
  @rollout = args[:rollout] if args.key?(:rollout)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end