Class: Google::Apis::OsconfigV1::PatchJobInstanceDetailsSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb

Overview

A summary of the current patch state across all instances that this patch job affects. Contains counts of instances in different states. These states map to InstancePatchState. List patch job instance details to see the specific states of each instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PatchJobInstanceDetailsSummary

Returns a new instance of PatchJobInstanceDetailsSummary.



3299
3300
3301
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3299

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acked_instance_countFixnum

Number of instances that have acked and will start shortly. Corresponds to the JSON property ackedInstanceCount

Returns:

  • (Fixnum)


3220
3221
3222
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3220

def acked_instance_count
  @acked_instance_count
end

#applying_patches_instance_countFixnum

Number of instances that are applying patches. Corresponds to the JSON property applyingPatchesInstanceCount

Returns:

  • (Fixnum)


3225
3226
3227
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3225

def applying_patches_instance_count
  @applying_patches_instance_count
end

#downloading_patches_instance_countFixnum

Number of instances that are downloading patches. Corresponds to the JSON property downloadingPatchesInstanceCount

Returns:

  • (Fixnum)


3230
3231
3232
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3230

def downloading_patches_instance_count
  @downloading_patches_instance_count
end

#failed_instance_countFixnum

Number of instances that failed. Corresponds to the JSON property failedInstanceCount

Returns:

  • (Fixnum)


3235
3236
3237
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3235

def failed_instance_count
  @failed_instance_count
end

#inactive_instance_countFixnum

Number of instances that are inactive. Corresponds to the JSON property inactiveInstanceCount

Returns:

  • (Fixnum)


3240
3241
3242
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3240

def inactive_instance_count
  @inactive_instance_count
end

#no_agent_detected_instance_countFixnum

Number of instances that do not appear to be running the agent. Check to ensure that the agent is installed, running, and able to communicate with the service. Corresponds to the JSON property noAgentDetectedInstanceCount

Returns:

  • (Fixnum)


3247
3248
3249
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3247

def no_agent_detected_instance_count
  @no_agent_detected_instance_count
end

#notified_instance_countFixnum

Number of instances notified about patch job. Corresponds to the JSON property notifiedInstanceCount

Returns:

  • (Fixnum)


3252
3253
3254
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3252

def notified_instance_count
  @notified_instance_count
end

#pending_instance_countFixnum

Number of instances pending patch job. Corresponds to the JSON property pendingInstanceCount

Returns:

  • (Fixnum)


3257
3258
3259
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3257

def pending_instance_count
  @pending_instance_count
end

#post_patch_step_instance_countFixnum

Number of instances that are running the post-patch step. Corresponds to the JSON property postPatchStepInstanceCount

Returns:

  • (Fixnum)


3262
3263
3264
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3262

def post_patch_step_instance_count
  @post_patch_step_instance_count
end

#pre_patch_step_instance_countFixnum

Number of instances that are running the pre-patch step. Corresponds to the JSON property prePatchStepInstanceCount

Returns:

  • (Fixnum)


3267
3268
3269
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3267

def pre_patch_step_instance_count
  @pre_patch_step_instance_count
end

#rebooting_instance_countFixnum

Number of instances rebooting. Corresponds to the JSON property rebootingInstanceCount

Returns:

  • (Fixnum)


3272
3273
3274
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3272

def rebooting_instance_count
  @rebooting_instance_count
end

#skipped_instance_countFixnum

Number of instances that were skipped during patching. Corresponds to the JSON property skippedInstanceCount

Returns:

  • (Fixnum)


3277
3278
3279
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3277

def skipped_instance_count
  @skipped_instance_count
end

#started_instance_countFixnum

Number of instances that have started. Corresponds to the JSON property startedInstanceCount

Returns:

  • (Fixnum)


3282
3283
3284
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3282

def started_instance_count
  @started_instance_count
end

#succeeded_instance_countFixnum

Number of instances that have completed successfully. Corresponds to the JSON property succeededInstanceCount

Returns:

  • (Fixnum)


3287
3288
3289
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3287

def succeeded_instance_count
  @succeeded_instance_count
end

#succeeded_reboot_required_instance_countFixnum

Number of instances that require reboot. Corresponds to the JSON property succeededRebootRequiredInstanceCount

Returns:

  • (Fixnum)


3292
3293
3294
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3292

def succeeded_reboot_required_instance_count
  @succeeded_reboot_required_instance_count
end

#timed_out_instance_countFixnum

Number of instances that exceeded the time out while applying the patch. Corresponds to the JSON property timedOutInstanceCount

Returns:

  • (Fixnum)


3297
3298
3299
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3297

def timed_out_instance_count
  @timed_out_instance_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3304

def update!(**args)
  @acked_instance_count = args[:acked_instance_count] if args.key?(:acked_instance_count)
  @applying_patches_instance_count = args[:applying_patches_instance_count] if args.key?(:applying_patches_instance_count)
  @downloading_patches_instance_count = args[:downloading_patches_instance_count] if args.key?(:downloading_patches_instance_count)
  @failed_instance_count = args[:failed_instance_count] if args.key?(:failed_instance_count)
  @inactive_instance_count = args[:inactive_instance_count] if args.key?(:inactive_instance_count)
  @no_agent_detected_instance_count = args[:no_agent_detected_instance_count] if args.key?(:no_agent_detected_instance_count)
  @notified_instance_count = args[:notified_instance_count] if args.key?(:notified_instance_count)
  @pending_instance_count = args[:pending_instance_count] if args.key?(:pending_instance_count)
  @post_patch_step_instance_count = args[:post_patch_step_instance_count] if args.key?(:post_patch_step_instance_count)
  @pre_patch_step_instance_count = args[:pre_patch_step_instance_count] if args.key?(:pre_patch_step_instance_count)
  @rebooting_instance_count = args[:rebooting_instance_count] if args.key?(:rebooting_instance_count)
  @skipped_instance_count = args[:skipped_instance_count] if args.key?(:skipped_instance_count)
  @started_instance_count = args[:started_instance_count] if args.key?(:started_instance_count)
  @succeeded_instance_count = args[:succeeded_instance_count] if args.key?(:succeeded_instance_count)
  @succeeded_reboot_required_instance_count = args[:succeeded_reboot_required_instance_count] if args.key?(:succeeded_reboot_required_instance_count)
  @timed_out_instance_count = args[:timed_out_instance_count] if args.key?(:timed_out_instance_count)
end