Class: Google::Apis::OsconfigV1::RecurringSchedule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb

Overview

Sets the time for recurring patch deployments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RecurringSchedule

Returns a new instance of RecurringSchedule.



3446
3447
3448
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3446

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

Optional. The end time at which a recurring patch deployment schedule is no longer active. Corresponds to the JSON property endTime

Returns:

  • (String)


3399
3400
3401
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3399

def end_time
  @end_time
end

#frequencyString

Required. The frequency unit of this recurring schedule. Corresponds to the JSON property frequency

Returns:

  • (String)


3404
3405
3406
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3404

def frequency
  @frequency
end

#last_execute_timeString

Output only. The time the last patch job ran successfully. Corresponds to the JSON property lastExecuteTime

Returns:

  • (String)


3409
3410
3411
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3409

def last_execute_time
  @last_execute_time
end

#monthlyGoogle::Apis::OsconfigV1::MonthlySchedule

Represents a monthly schedule. An example of a valid monthly schedule is "on the third Tuesday of the month" or "on the 15th of the month". Corresponds to the JSON property monthly



3415
3416
3417
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3415

def monthly
  @monthly
end

#next_execute_timeString

Output only. The time the next patch job is scheduled to run. Corresponds to the JSON property nextExecuteTime

Returns:

  • (String)


3420
3421
3422
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3420

def next_execute_time
  @next_execute_time
end

#start_timeString

Optional. The time that the recurring schedule becomes effective. Defaults to create_time of the patch deployment. Corresponds to the JSON property startTime

Returns:

  • (String)


3426
3427
3428
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3426

def start_time
  @start_time
end

#time_of_dayGoogle::Apis::OsconfigV1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property timeOfDay



3433
3434
3435
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3433

def time_of_day
  @time_of_day
end

#time_zoneGoogle::Apis::OsconfigV1::TimeZone

Represents a time zone from the IANA Time Zone Database. Corresponds to the JSON property timeZone



3439
3440
3441
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3439

def time_zone
  @time_zone
end

#weeklyGoogle::Apis::OsconfigV1::WeeklySchedule

Represents a weekly schedule. Corresponds to the JSON property weekly



3444
3445
3446
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3444

def weekly
  @weekly
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3451

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @frequency = args[:frequency] if args.key?(:frequency)
  @last_execute_time = args[:last_execute_time] if args.key?(:last_execute_time)
  @monthly = args[:monthly] if args.key?(:monthly)
  @next_execute_time = args[:next_execute_time] if args.key?(:next_execute_time)
  @start_time = args[:start_time] if args.key?(:start_time)
  @time_of_day = args[:time_of_day] if args.key?(:time_of_day)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @weekly = args[:weekly] if args.key?(:weekly)
end