Class: Google::Apis::OsconfigV1::VulnerabilityReportVulnerability

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb

Overview

A vulnerability affecting the VM instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VulnerabilityReportVulnerability

Returns a new instance of VulnerabilityReportVulnerability.



3732
3733
3734
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3732

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#available_inventory_item_idsArray<String>

Corresponds to the AVAILABLE_PACKAGE inventory item on the VM. If the vulnerability report was not updated after the VM inventory update, these values might not display in VM inventory. If there is no available fix, the field is empty. The inventory_item value specifies the latest SoftwarePackage available to the VM that fixes the vulnerability. Corresponds to the JSON property availableInventoryItemIds

Returns:

  • (Array<String>)


3700
3701
3702
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3700

def available_inventory_item_ids
  @available_inventory_item_ids
end

#create_timeString

The timestamp for when the vulnerability was first detected. Corresponds to the JSON property createTime

Returns:

  • (String)


3705
3706
3707
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3705

def create_time
  @create_time
end

#detailsGoogle::Apis::OsconfigV1::VulnerabilityReportVulnerabilityDetails

Contains metadata information for the vulnerability. This information is collected from the upstream feed of the operating system. Corresponds to the JSON property details



3711
3712
3713
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3711

def details
  @details
end

#installed_inventory_item_idsArray<String>

Corresponds to the INSTALLED_PACKAGE inventory item on the VM. This field displays the inventory items affected by this vulnerability. If the vulnerability report was not updated after the VM inventory update, these values might not display in VM inventory. For some distros, this field may be empty. Corresponds to the JSON property installedInventoryItemIds

Returns:

  • (Array<String>)


3720
3721
3722
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3720

def installed_inventory_item_ids
  @installed_inventory_item_ids
end

#itemsArray<Google::Apis::OsconfigV1::VulnerabilityReportVulnerabilityItem>

List of items affected by the vulnerability. Corresponds to the JSON property items



3725
3726
3727
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3725

def items
  @items
end

#update_timeString

The timestamp for when the vulnerability was last modified. Corresponds to the JSON property updateTime

Returns:

  • (String)


3730
3731
3732
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3730

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3737
3738
3739
3740
3741
3742
3743
3744
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3737

def update!(**args)
  @available_inventory_item_ids = args[:available_inventory_item_ids] if args.key?(:available_inventory_item_ids)
  @create_time = args[:create_time] if args.key?(:create_time)
  @details = args[:details] if args.key?(:details)
  @installed_inventory_item_ids = args[:installed_inventory_item_ids] if args.key?(:installed_inventory_item_ids)
  @items = args[:items] if args.key?(:items)
  @update_time = args[:update_time] if args.key?(:update_time)
end