Class: Google::Apis::OsconfigV1::VulnerabilityReportVulnerabilityDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb

Overview

Contains metadata information for the vulnerability. This information is collected from the upstream feed of the operating system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VulnerabilityReportVulnerabilityDetails

Returns a new instance of VulnerabilityReportVulnerabilityDetails.



3785
3786
3787
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3785

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cveString

The CVE of the vulnerability. CVE cannot be empty and the combination of should be unique across vulnerabilities for a VM. Corresponds to the JSON property cve

Returns:

  • (String)


3756
3757
3758
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3756

def cve
  @cve
end

#cvss_v2_scoreFloat

The CVSS V2 score of this vulnerability. CVSS V2 score is on a scale of 0 - 10 where 0 indicates low severity and 10 indicates high severity. Corresponds to the JSON property cvssV2Score

Returns:

  • (Float)


3762
3763
3764
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3762

def cvss_v2_score
  @cvss_v2_score
end

#cvss_v3Google::Apis::OsconfigV1::CvsSv3

Common Vulnerability Scoring System version 3. For details, see https://www. first.org/cvss/specification-document Corresponds to the JSON property cvssV3



3768
3769
3770
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3768

def cvss_v3
  @cvss_v3
end

#descriptionString

The note or description describing the vulnerability from the distro. Corresponds to the JSON property description

Returns:

  • (String)


3773
3774
3775
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3773

def description
  @description
end

#referencesArray<Google::Apis::OsconfigV1::VulnerabilityReportVulnerabilityDetailsReference>

Corresponds to the references attached to the VulnerabilityDetails. Corresponds to the JSON property references



3778
3779
3780
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3778

def references
  @references
end

#severityString

Assigned severity/impact ranking from the distro. Corresponds to the JSON property severity

Returns:

  • (String)


3783
3784
3785
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3783

def severity
  @severity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3790
3791
3792
3793
3794
3795
3796
3797
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3790

def update!(**args)
  @cve = args[:cve] if args.key?(:cve)
  @cvss_v2_score = args[:cvss_v2_score] if args.key?(:cvss_v2_score)
  @cvss_v3 = args[:cvss_v3] if args.key?(:cvss_v3)
  @description = args[:description] if args.key?(:description)
  @references = args[:references] if args.key?(:references)
  @severity = args[:severity] if args.key?(:severity)
end