Class: Google::Apis::OsconfigV1::WeekDayOfMonth

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb

Overview

Represents one week day in a month. An example is "the 4th Sunday".

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WeekDayOfMonth

Returns a new instance of WeekDayOfMonth.



4109
4110
4111
# File 'lib/google/apis/osconfig_v1/classes.rb', line 4109

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#day_of_weekString

Required. A day of the week. Corresponds to the JSON property dayOfWeek

Returns:

  • (String)


4090
4091
4092
# File 'lib/google/apis/osconfig_v1/classes.rb', line 4090

def day_of_week
  @day_of_week
end

#day_offsetFixnum

Optional. Represents the number of days before or after the given week day of month that the patch deployment is scheduled for. For example if week_ordinal and day_of_week values point to the second Tuesday of the month and the day_offset value is set to 3, patch deployment takes place three days after the second Tuesday of the month. If this value is negative, for example -5, patches are deployed five days before the second Tuesday of the month. Allowed values are in range [-30, 30]. Corresponds to the JSON property dayOffset

Returns:

  • (Fixnum)


4101
4102
4103
# File 'lib/google/apis/osconfig_v1/classes.rb', line 4101

def day_offset
  @day_offset
end

#week_ordinalFixnum

Required. Week number in a month. 1-4 indicates the 1st to 4th week of the month. -1 indicates the last week of the month. Corresponds to the JSON property weekOrdinal

Returns:

  • (Fixnum)


4107
4108
4109
# File 'lib/google/apis/osconfig_v1/classes.rb', line 4107

def week_ordinal
  @week_ordinal
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4114
4115
4116
4117
4118
# File 'lib/google/apis/osconfig_v1/classes.rb', line 4114

def update!(**args)
  @day_of_week = args[:day_of_week] if args.key?(:day_of_week)
  @day_offset = args[:day_offset] if args.key?(:day_offset)
  @week_ordinal = args[:week_ordinal] if args.key?(:week_ordinal)
end