Class: Google::Apis::OsconfigV1::Inventory
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1::Inventory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb
Overview
This API resource represents the available inventory data for a Compute Engine virtual machine (VM) instance at a given point in time. You can use this API resource to determine the inventory data of your VM. For more information, see Information provided by OS inventory management.
Instance Attribute Summary collapse
-
#items ⇒ Hash<String,Google::Apis::OsconfigV1::InventoryItem>
Inventory items related to the VM keyed by an opaque unique identifier for each inventory item.
-
#name ⇒ String
Output only.
-
#os_info ⇒ Google::Apis::OsconfigV1::InventoryOsInfo
Operating system information for the VM.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Inventory
constructor
A new instance of Inventory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Inventory
Returns a new instance of Inventory.
629 630 631 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 629 def initialize(**args) update!(**args) end |
Instance Attribute Details
#items ⇒ Hash<String,Google::Apis::OsconfigV1::InventoryItem>
Inventory items related to the VM keyed by an opaque unique identifier for
each inventory item. The identifier is unique to each distinct and addressable
inventory item and will change, when there is a new package version.
Corresponds to the JSON property items
611 612 613 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 611 def items @items end |
#name ⇒ String
Output only. The Inventory API resource name. Format: projects/
project_number/locations/location/instances/instance_id/inventory
Corresponds to the JSON property name
617 618 619 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 617 def name @name end |
#os_info ⇒ Google::Apis::OsconfigV1::InventoryOsInfo
Operating system information for the VM.
Corresponds to the JSON property osInfo
622 623 624 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 622 def os_info @os_info end |
#update_time ⇒ String
Output only. Timestamp of the last reported inventory for the VM.
Corresponds to the JSON property updateTime
627 628 629 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 627 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
634 635 636 637 638 639 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 634 def update!(**args) @items = args[:items] if args.key?(:items) @name = args[:name] if args.key?(:name) @os_info = args[:os_info] if args.key?(:os_info) @update_time = args[:update_time] if args.key?(:update_time) end |