Class: Google::Apis::OsconfigV1::InventoryWindowsUpdatePackage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb

Overview

Details related to a Windows Update package. Field data and names are taken from Windows Update API IUpdate Interface: https://docs.microsoft.com/en-us/ windows/win32/api/_wua/ Descriptive fields like title, and description are localized based on the locale of the VM being updated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InventoryWindowsUpdatePackage

Returns a new instance of InventoryWindowsUpdatePackage.



1191
1192
1193
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1191

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoriesArray<Google::Apis::OsconfigV1::InventoryWindowsUpdatePackageWindowsUpdateCategory>

The categories that are associated with this update package. Corresponds to the JSON property categories



1148
1149
1150
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1148

def categories
  @categories
end

#descriptionString

The localized description of the update package. Corresponds to the JSON property description

Returns:

  • (String)


1153
1154
1155
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1153

def description
  @description
end

#kb_article_idsArray<String>

A collection of Microsoft Knowledge Base article IDs that are associated with the update package. Corresponds to the JSON property kbArticleIds

Returns:

  • (Array<String>)


1159
1160
1161
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1159

def kb_article_ids
  @kb_article_ids
end

#last_deployment_change_timeString

The last published date of the update, in (UTC) date and time. Corresponds to the JSON property lastDeploymentChangeTime

Returns:

  • (String)


1164
1165
1166
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1164

def last_deployment_change_time
  @last_deployment_change_time
end

#more_info_urlsArray<String>

A collection of URLs that provide more information about the update package. Corresponds to the JSON property moreInfoUrls

Returns:

  • (Array<String>)


1169
1170
1171
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1169

def more_info_urls
  @more_info_urls
end

#revision_numberFixnum

The revision number of this update package. Corresponds to the JSON property revisionNumber

Returns:

  • (Fixnum)


1174
1175
1176
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1174

def revision_number
  @revision_number
end

#support_urlString

A hyperlink to the language-specific support information for the update. Corresponds to the JSON property supportUrl

Returns:

  • (String)


1179
1180
1181
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1179

def support_url
  @support_url
end

#titleString

The localized title of the update package. Corresponds to the JSON property title

Returns:

  • (String)


1184
1185
1186
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1184

def title
  @title
end

#update_idString

Gets the identifier of an update package. Stays the same across revisions. Corresponds to the JSON property updateId

Returns:

  • (String)


1189
1190
1191
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1189

def update_id
  @update_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1196

def update!(**args)
  @categories = args[:categories] if args.key?(:categories)
  @description = args[:description] if args.key?(:description)
  @kb_article_ids = args[:kb_article_ids] if args.key?(:kb_article_ids)
  @last_deployment_change_time = args[:last_deployment_change_time] if args.key?(:last_deployment_change_time)
  @more_info_urls = args[:more_info_urls] if args.key?(:more_info_urls)
  @revision_number = args[:revision_number] if args.key?(:revision_number)
  @support_url = args[:support_url] if args.key?(:support_url)
  @title = args[:title] if args.key?(:title)
  @update_id = args[:update_id] if args.key?(:update_id)
end