Class: Google::Apis::OsconfigV1::OsPolicyAssignmentInstanceFilter
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1::OsPolicyAssignmentInstanceFilter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb
Overview
Filters to select target VMs for an assignment. If more than one filter criteria is specified below, a VM will be selected if and only if it satisfies all of them.
Instance Attribute Summary collapse
-
#all ⇒ Boolean
(also: #all?)
Target all VMs in the project.
-
#exclusion_labels ⇒ Array<Google::Apis::OsconfigV1::OsPolicyAssignmentLabelSet>
List of label sets used for VM exclusion.
-
#inclusion_labels ⇒ Array<Google::Apis::OsconfigV1::OsPolicyAssignmentLabelSet>
List of label sets used for VM inclusion.
-
#inventories ⇒ Array<Google::Apis::OsconfigV1::OsPolicyAssignmentInstanceFilterInventory>
List of inventories to select VMs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OsPolicyAssignmentInstanceFilter
constructor
A new instance of OsPolicyAssignmentInstanceFilter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OsPolicyAssignmentInstanceFilter
Returns a new instance of OsPolicyAssignmentInstanceFilter.
1549 1550 1551 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1549 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all ⇒ Boolean Also known as: all?
Target all VMs in the project. If true, no other criteria is permitted.
Corresponds to the JSON property all
1527 1528 1529 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1527 def all @all end |
#exclusion_labels ⇒ Array<Google::Apis::OsconfigV1::OsPolicyAssignmentLabelSet>
List of label sets used for VM exclusion. If the list has more than one label
set, the VM is excluded if any of the label sets are applicable for the VM.
Corresponds to the JSON property exclusionLabels
1534 1535 1536 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1534 def exclusion_labels @exclusion_labels end |
#inclusion_labels ⇒ Array<Google::Apis::OsconfigV1::OsPolicyAssignmentLabelSet>
List of label sets used for VM inclusion. If the list has more than one
LabelSet, the VM is included if any of the label sets are applicable for the
VM.
Corresponds to the JSON property inclusionLabels
1541 1542 1543 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1541 def inclusion_labels @inclusion_labels end |
#inventories ⇒ Array<Google::Apis::OsconfigV1::OsPolicyAssignmentInstanceFilterInventory>
List of inventories to select VMs. A VM is selected if its inventory data
matches at least one of the following inventories.
Corresponds to the JSON property inventories
1547 1548 1549 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1547 def inventories @inventories end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1554 1555 1556 1557 1558 1559 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 1554 def update!(**args) @all = args[:all] if args.key?(:all) @exclusion_labels = args[:exclusion_labels] if args.key?(:exclusion_labels) @inclusion_labels = args[:inclusion_labels] if args.key?(:inclusion_labels) @inventories = args[:inventories] if args.key?(:inventories) end |