Class: Google::Apis::OsconfigV1::OsPolicyResourceFile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb

Overview

A remote or local file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OsPolicyResourceFile

Returns a new instance of OsPolicyResourceFile.



2325
2326
2327
# File 'lib/google/apis/osconfig_v1/classes.rb', line 2325

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_insecureBoolean Also known as: allow_insecure?

Defaults to false. When false, files are subject to validations based on the file type: Remote: A checksum must be specified. Cloud Storage: An object generation number must be specified. Corresponds to the JSON property allowInsecure

Returns:

  • (Boolean)


2307
2308
2309
# File 'lib/google/apis/osconfig_v1/classes.rb', line 2307

def allow_insecure
  @allow_insecure
end

#gcsGoogle::Apis::OsconfigV1::OsPolicyResourceFileGcs

Specifies a file available as a Cloud Storage Object. Corresponds to the JSON property gcs



2313
2314
2315
# File 'lib/google/apis/osconfig_v1/classes.rb', line 2313

def gcs
  @gcs
end

#local_pathString

A local path within the VM to use. Corresponds to the JSON property localPath

Returns:

  • (String)


2318
2319
2320
# File 'lib/google/apis/osconfig_v1/classes.rb', line 2318

def local_path
  @local_path
end

#remoteGoogle::Apis::OsconfigV1::OsPolicyResourceFileRemote

Specifies a file available via some URI. Corresponds to the JSON property remote



2323
2324
2325
# File 'lib/google/apis/osconfig_v1/classes.rb', line 2323

def remote
  @remote
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2330
2331
2332
2333
2334
2335
# File 'lib/google/apis/osconfig_v1/classes.rb', line 2330

def update!(**args)
  @allow_insecure = args[:allow_insecure] if args.key?(:allow_insecure)
  @gcs = args[:gcs] if args.key?(:gcs)
  @local_path = args[:local_path] if args.key?(:local_path)
  @remote = args[:remote] if args.key?(:remote)
end