Class: Google::Apis::OsconfigV1::PatchDeployment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb

Overview

Patch deployments are configurations that individual patch jobs use to complete a patch. These configurations include instance filter, package repository settings, and a schedule. For more information about creating and managing patch deployments, see Scheduling patch jobs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PatchDeployment

Returns a new instance of PatchDeployment.



3155
3156
3157
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3155

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time the patch deployment was created. Timestamp is in RFC3339 text format. Corresponds to the JSON property createTime

Returns:

  • (String)


3087
3088
3089
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3087

def create_time
  @create_time
end

#descriptionString

Optional. Description of the patch deployment. Length of the description is limited to 1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


3093
3094
3095
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3093

def description
  @description
end

#durationString

Optional. Duration of the patch. After the duration ends, the patch times out. Corresponds to the JSON property duration

Returns:

  • (String)


3098
3099
3100
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3098

def duration
  @duration
end

#instance_filterGoogle::Apis::OsconfigV1::PatchInstanceFilter

A filter to target VM instances for patching. The targeted VMs must meet all criteria specified. So if both labels and zones are specified, the patch job targets only VMs with those labels and in those zones. Corresponds to the JSON property instanceFilter



3105
3106
3107
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3105

def instance_filter
  @instance_filter
end

#last_execute_timeString

Output only. The last time a patch job was started by this deployment. Timestamp is in RFC3339 text format. Corresponds to the JSON property lastExecuteTime

Returns:

  • (String)


3111
3112
3113
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3111

def last_execute_time
  @last_execute_time
end

#nameString

Unique name for the patch deployment resource in a project. The patch deployment name is in the form: projects/project_id/patchDeployments/ patch_deployment_id`. This field is ignored when you create a new patch deployment. Corresponds to the JSON propertyname`

Returns:

  • (String)


3119
3120
3121
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3119

def name
  @name
end

#one_time_scheduleGoogle::Apis::OsconfigV1::OneTimeSchedule

Sets the time for a one time patch deployment. Timestamp is in RFC3339 text format. Corresponds to the JSON property oneTimeSchedule



3125
3126
3127
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3125

def one_time_schedule
  @one_time_schedule
end

#patch_configGoogle::Apis::OsconfigV1::PatchConfig

Patch configuration specifications. Contains details on how to apply the patch( es) to a VM instance. Corresponds to the JSON property patchConfig



3131
3132
3133
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3131

def patch_config
  @patch_config
end

#recurring_scheduleGoogle::Apis::OsconfigV1::RecurringSchedule

Sets the time for recurring patch deployments. Corresponds to the JSON property recurringSchedule



3136
3137
3138
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3136

def recurring_schedule
  @recurring_schedule
end

#rolloutGoogle::Apis::OsconfigV1::PatchRollout

Patch rollout configuration specifications. Contains details on the concurrency control when applying patch(es) to all targeted VMs. Corresponds to the JSON property rollout



3142
3143
3144
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3142

def rollout
  @rollout
end

#stateString

Output only. Current state of the patch deployment. Corresponds to the JSON property state

Returns:

  • (String)


3147
3148
3149
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3147

def state
  @state
end

#update_timeString

Output only. Time the patch deployment was last updated. Timestamp is in RFC3339 text format. Corresponds to the JSON property updateTime

Returns:

  • (String)


3153
3154
3155
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3153

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3160
3161
3162
3163
3164
3165
3166
3167
3168
3169
3170
3171
3172
3173
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3160

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @duration = args[:duration] if args.key?(:duration)
  @instance_filter = args[:instance_filter] if args.key?(:instance_filter)
  @last_execute_time = args[:last_execute_time] if args.key?(:last_execute_time)
  @name = args[:name] if args.key?(:name)
  @one_time_schedule = args[:one_time_schedule] if args.key?(:one_time_schedule)
  @patch_config = args[:patch_config] if args.key?(:patch_config)
  @recurring_schedule = args[:recurring_schedule] if args.key?(:recurring_schedule)
  @rollout = args[:rollout] if args.key?(:rollout)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end