Class: Google::Apis::OsconfigV1::PatchInstanceFilter
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1::PatchInstanceFilter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb
Overview
A filter to target VM instances for patching. The targeted VMs must meet all criteria specified. So if both labels and zones are specified, the patch job targets only VMs with those labels and in those zones.
Instance Attribute Summary collapse
-
#all ⇒ Boolean
(also: #all?)
Target all VM instances in the project.
-
#group_labels ⇒ Array<Google::Apis::OsconfigV1::PatchInstanceFilterGroupLabel>
Targets VM instances matching ANY of these GroupLabels.
-
#instance_name_prefixes ⇒ Array<String>
Targets VMs whose name starts with one of these prefixes.
-
#instances ⇒ Array<String>
Targets any of the VM instances specified.
-
#zones ⇒ Array<String>
Targets VM instances in ANY of these zones.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PatchInstanceFilter
constructor
A new instance of PatchInstanceFilter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PatchInstanceFilter
Returns a new instance of PatchInstanceFilter.
3217 3218 3219 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3217 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all ⇒ Boolean Also known as: all?
Target all VM instances in the project. If true, no other criteria is
permitted.
Corresponds to the JSON property all
3186 3187 3188 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3186 def all @all end |
#group_labels ⇒ Array<Google::Apis::OsconfigV1::PatchInstanceFilterGroupLabel>
Targets VM instances matching ANY of these GroupLabels. This allows targeting
of disparate groups of VM instances.
Corresponds to the JSON property groupLabels
3193 3194 3195 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3193 def group_labels @group_labels end |
#instance_name_prefixes ⇒ Array<String>
Targets VMs whose name starts with one of these prefixes. Similar to labels,
this is another way to group VMs when targeting configs, for example prefix="
prod-".
Corresponds to the JSON property instanceNamePrefixes
3200 3201 3202 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3200 def instance_name_prefixes @instance_name_prefixes end |
#instances ⇒ Array<String>
Targets any of the VM instances specified. Instances are specified by their
URI in the form zones/[ZONE]/instances/[INSTANCE_NAME], projects/[
PROJECT_ID]/zones/[ZONE]/instances/[INSTANCE_NAME], or https://www.
googleapis.com/compute/v1/projects/[PROJECT_ID]/zones/[ZONE]/instances/[
INSTANCE_NAME]
Corresponds to the JSON property instances
3209 3210 3211 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3209 def instances @instances end |
#zones ⇒ Array<String>
Targets VM instances in ANY of these zones. Leave empty to target VM instances
in any zone.
Corresponds to the JSON property zones
3215 3216 3217 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3215 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3222 3223 3224 3225 3226 3227 3228 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3222 def update!(**args) @all = args[:all] if args.key?(:all) @group_labels = args[:group_labels] if args.key?(:group_labels) @instance_name_prefixes = args[:instance_name_prefixes] if args.key?(:instance_name_prefixes) @instances = args[:instances] if args.key?(:instances) @zones = args[:zones] if args.key?(:zones) end |