Class: Google::Apis::OsconfigV1::PatchJob
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1::PatchJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb
Overview
A high level representation of a patch job that is either in progress or has
completed. Instance details are not included in the job. To paginate through
instance details, use ListPatchJobInstanceDetails. For more information
about patch jobs, see Creating patch jobs.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Time this patch job was created.
-
#description ⇒ String
Description of the patch job.
-
#display_name ⇒ String
Display name for this patch job.
-
#dry_run ⇒ Boolean
(also: #dry_run?)
If this patch job is a dry run, the agent reports that it has finished without running any updates on the VM instance.
-
#duration ⇒ String
Duration of the patch job.
-
#error_message ⇒ String
If this patch job failed, this message provides information about the failure.
-
#instance_details_summary ⇒ Google::Apis::OsconfigV1::PatchJobInstanceDetailsSummary
A summary of the current patch state across all instances that this patch job affects.
-
#instance_filter ⇒ Google::Apis::OsconfigV1::PatchInstanceFilter
A filter to target VM instances for patching.
-
#name ⇒ String
Unique identifier for this patch job in the form
projects/*/patchJobs/*Corresponds to the JSON propertyname. -
#patch_config ⇒ Google::Apis::OsconfigV1::PatchConfig
Patch configuration specifications.
-
#patch_deployment ⇒ String
Output only.
-
#percent_complete ⇒ Float
Reflects the overall progress of the patch job in the range of 0.0 being no progress to 100.0 being complete.
-
#rollout ⇒ Google::Apis::OsconfigV1::PatchRollout
Patch rollout configuration specifications.
-
#state ⇒ String
The current state of the PatchJob.
-
#update_time ⇒ String
Last time this patch job was updated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PatchJob
constructor
A new instance of PatchJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PatchJob
Returns a new instance of PatchJob.
3350 3351 3352 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3350 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Time this patch job was created.
Corresponds to the JSON property createTime
3267 3268 3269 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3267 def create_time @create_time end |
#description ⇒ String
Description of the patch job. Length of the description is limited to 1024
characters.
Corresponds to the JSON property description
3273 3274 3275 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3273 def description @description end |
#display_name ⇒ String
Display name for this patch job. This is not a unique identifier.
Corresponds to the JSON property displayName
3278 3279 3280 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3278 def display_name @display_name end |
#dry_run ⇒ Boolean Also known as: dry_run?
If this patch job is a dry run, the agent reports that it has finished without
running any updates on the VM instance.
Corresponds to the JSON property dryRun
3284 3285 3286 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3284 def dry_run @dry_run end |
#duration ⇒ String
Duration of the patch job. After the duration ends, the patch job times out.
Corresponds to the JSON property duration
3290 3291 3292 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3290 def duration @duration end |
#error_message ⇒ String
If this patch job failed, this message provides information about the failure.
Corresponds to the JSON property errorMessage
3295 3296 3297 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3295 def @error_message end |
#instance_details_summary ⇒ Google::Apis::OsconfigV1::PatchJobInstanceDetailsSummary
A summary of the current patch state across all instances that this patch job
affects. Contains counts of instances in different states. These states map to
InstancePatchState. List patch job instance details to see the specific
states of each instance.
Corresponds to the JSON property instanceDetailsSummary
3303 3304 3305 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3303 def instance_details_summary @instance_details_summary end |
#instance_filter ⇒ Google::Apis::OsconfigV1::PatchInstanceFilter
A filter to target VM instances for patching. The targeted VMs must meet all
criteria specified. So if both labels and zones are specified, the patch job
targets only VMs with those labels and in those zones.
Corresponds to the JSON property instanceFilter
3310 3311 3312 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3310 def instance_filter @instance_filter end |
#name ⇒ String
Unique identifier for this patch job in the form projects/*/patchJobs/*
Corresponds to the JSON property name
3315 3316 3317 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3315 def name @name end |
#patch_config ⇒ Google::Apis::OsconfigV1::PatchConfig
Patch configuration specifications. Contains details on how to apply the patch(
es) to a VM instance.
Corresponds to the JSON property patchConfig
3321 3322 3323 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3321 def patch_config @patch_config end |
#patch_deployment ⇒ String
Output only. Name of the patch deployment that created this patch job.
Corresponds to the JSON property patchDeployment
3326 3327 3328 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3326 def patch_deployment @patch_deployment end |
#percent_complete ⇒ Float
Reflects the overall progress of the patch job in the range of 0.0 being no
progress to 100.0 being complete.
Corresponds to the JSON property percentComplete
3332 3333 3334 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3332 def percent_complete @percent_complete end |
#rollout ⇒ Google::Apis::OsconfigV1::PatchRollout
Patch rollout configuration specifications. Contains details on the
concurrency control when applying patch(es) to all targeted VMs.
Corresponds to the JSON property rollout
3338 3339 3340 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3338 def rollout @rollout end |
#state ⇒ String
The current state of the PatchJob.
Corresponds to the JSON property state
3343 3344 3345 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3343 def state @state end |
#update_time ⇒ String
Last time this patch job was updated.
Corresponds to the JSON property updateTime
3348 3349 3350 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3348 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3355 3356 3357 3358 3359 3360 3361 3362 3363 3364 3365 3366 3367 3368 3369 3370 3371 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3355 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @dry_run = args[:dry_run] if args.key?(:dry_run) @duration = args[:duration] if args.key?(:duration) @error_message = args[:error_message] if args.key?(:error_message) @instance_details_summary = args[:instance_details_summary] if args.key?(:instance_details_summary) @instance_filter = args[:instance_filter] if args.key?(:instance_filter) @name = args[:name] if args.key?(:name) @patch_config = args[:patch_config] if args.key?(:patch_config) @patch_deployment = args[:patch_deployment] if args.key?(:patch_deployment) @percent_complete = args[:percent_complete] if args.key?(:percent_complete) @rollout = args[:rollout] if args.key?(:rollout) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |