Class: Google::Apis::OsconfigV1::PatchJobInstanceDetailsSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb

Overview

A summary of the current patch state across all instances that this patch job affects. Contains counts of instances in different states. These states map to InstancePatchState. List patch job instance details to see the specific states of each instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PatchJobInstanceDetailsSummary

Returns a new instance of PatchJobInstanceDetailsSummary.



3510
3511
3512
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3510

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acked_instance_countFixnum

Number of instances that have acked and will start shortly. Corresponds to the JSON property ackedInstanceCount

Returns:

  • (Fixnum)


3431
3432
3433
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3431

def acked_instance_count
  @acked_instance_count
end

#applying_patches_instance_countFixnum

Number of instances that are applying patches. Corresponds to the JSON property applyingPatchesInstanceCount

Returns:

  • (Fixnum)


3436
3437
3438
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3436

def applying_patches_instance_count
  @applying_patches_instance_count
end

#downloading_patches_instance_countFixnum

Number of instances that are downloading patches. Corresponds to the JSON property downloadingPatchesInstanceCount

Returns:

  • (Fixnum)


3441
3442
3443
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3441

def downloading_patches_instance_count
  @downloading_patches_instance_count
end

#failed_instance_countFixnum

Number of instances that failed. Corresponds to the JSON property failedInstanceCount

Returns:

  • (Fixnum)


3446
3447
3448
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3446

def failed_instance_count
  @failed_instance_count
end

#inactive_instance_countFixnum

Number of instances that are inactive. Corresponds to the JSON property inactiveInstanceCount

Returns:

  • (Fixnum)


3451
3452
3453
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3451

def inactive_instance_count
  @inactive_instance_count
end

#no_agent_detected_instance_countFixnum

Number of instances that do not appear to be running the agent. Check to ensure that the agent is installed, running, and able to communicate with the service. Corresponds to the JSON property noAgentDetectedInstanceCount

Returns:

  • (Fixnum)


3458
3459
3460
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3458

def no_agent_detected_instance_count
  @no_agent_detected_instance_count
end

#notified_instance_countFixnum

Number of instances notified about patch job. Corresponds to the JSON property notifiedInstanceCount

Returns:

  • (Fixnum)


3463
3464
3465
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3463

def notified_instance_count
  @notified_instance_count
end

#pending_instance_countFixnum

Number of instances pending patch job. Corresponds to the JSON property pendingInstanceCount

Returns:

  • (Fixnum)


3468
3469
3470
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3468

def pending_instance_count
  @pending_instance_count
end

#post_patch_step_instance_countFixnum

Number of instances that are running the post-patch step. Corresponds to the JSON property postPatchStepInstanceCount

Returns:

  • (Fixnum)


3473
3474
3475
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3473

def post_patch_step_instance_count
  @post_patch_step_instance_count
end

#pre_patch_step_instance_countFixnum

Number of instances that are running the pre-patch step. Corresponds to the JSON property prePatchStepInstanceCount

Returns:

  • (Fixnum)


3478
3479
3480
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3478

def pre_patch_step_instance_count
  @pre_patch_step_instance_count
end

#rebooting_instance_countFixnum

Number of instances rebooting. Corresponds to the JSON property rebootingInstanceCount

Returns:

  • (Fixnum)


3483
3484
3485
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3483

def rebooting_instance_count
  @rebooting_instance_count
end

#skipped_instance_countFixnum

Number of instances that were skipped during patching. Corresponds to the JSON property skippedInstanceCount

Returns:

  • (Fixnum)


3488
3489
3490
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3488

def skipped_instance_count
  @skipped_instance_count
end

#started_instance_countFixnum

Number of instances that have started. Corresponds to the JSON property startedInstanceCount

Returns:

  • (Fixnum)


3493
3494
3495
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3493

def started_instance_count
  @started_instance_count
end

#succeeded_instance_countFixnum

Number of instances that have completed successfully. Corresponds to the JSON property succeededInstanceCount

Returns:

  • (Fixnum)


3498
3499
3500
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3498

def succeeded_instance_count
  @succeeded_instance_count
end

#succeeded_reboot_required_instance_countFixnum

Number of instances that require reboot. Corresponds to the JSON property succeededRebootRequiredInstanceCount

Returns:

  • (Fixnum)


3503
3504
3505
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3503

def succeeded_reboot_required_instance_count
  @succeeded_reboot_required_instance_count
end

#timed_out_instance_countFixnum

Number of instances that exceeded the time out while applying the patch. Corresponds to the JSON property timedOutInstanceCount

Returns:

  • (Fixnum)


3508
3509
3510
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3508

def timed_out_instance_count
  @timed_out_instance_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
3527
3528
3529
3530
3531
3532
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3515

def update!(**args)
  @acked_instance_count = args[:acked_instance_count] if args.key?(:acked_instance_count)
  @applying_patches_instance_count = args[:applying_patches_instance_count] if args.key?(:applying_patches_instance_count)
  @downloading_patches_instance_count = args[:downloading_patches_instance_count] if args.key?(:downloading_patches_instance_count)
  @failed_instance_count = args[:failed_instance_count] if args.key?(:failed_instance_count)
  @inactive_instance_count = args[:inactive_instance_count] if args.key?(:inactive_instance_count)
  @no_agent_detected_instance_count = args[:no_agent_detected_instance_count] if args.key?(:no_agent_detected_instance_count)
  @notified_instance_count = args[:notified_instance_count] if args.key?(:notified_instance_count)
  @pending_instance_count = args[:pending_instance_count] if args.key?(:pending_instance_count)
  @post_patch_step_instance_count = args[:post_patch_step_instance_count] if args.key?(:post_patch_step_instance_count)
  @pre_patch_step_instance_count = args[:pre_patch_step_instance_count] if args.key?(:pre_patch_step_instance_count)
  @rebooting_instance_count = args[:rebooting_instance_count] if args.key?(:rebooting_instance_count)
  @skipped_instance_count = args[:skipped_instance_count] if args.key?(:skipped_instance_count)
  @started_instance_count = args[:started_instance_count] if args.key?(:started_instance_count)
  @succeeded_instance_count = args[:succeeded_instance_count] if args.key?(:succeeded_instance_count)
  @succeeded_reboot_required_instance_count = args[:succeeded_reboot_required_instance_count] if args.key?(:succeeded_reboot_required_instance_count)
  @timed_out_instance_count = args[:timed_out_instance_count] if args.key?(:timed_out_instance_count)
end