Class: Google::Apis::OsconfigV1::RecurringSchedule
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1::RecurringSchedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb
Overview
Sets the time for recurring patch deployments.
Instance Attribute Summary collapse
-
#end_time ⇒ String
Optional.
-
#frequency ⇒ String
Required.
-
#last_execute_time ⇒ String
Output only.
-
#monthly ⇒ Google::Apis::OsconfigV1::MonthlySchedule
Represents a monthly schedule.
-
#next_execute_time ⇒ String
Output only.
-
#start_time ⇒ String
Optional.
-
#time_of_day ⇒ Google::Apis::OsconfigV1::TimeOfDay
Represents a time of day.
-
#time_zone ⇒ Google::Apis::OsconfigV1::TimeZone
Represents a time zone from the IANA Time Zone Database.
-
#weekly ⇒ Google::Apis::OsconfigV1::WeeklySchedule
Represents a weekly schedule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RecurringSchedule
constructor
A new instance of RecurringSchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RecurringSchedule
Returns a new instance of RecurringSchedule.
3657 3658 3659 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3657 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
Optional. The end time at which a recurring patch deployment schedule is no
longer active.
Corresponds to the JSON property endTime
3610 3611 3612 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3610 def end_time @end_time end |
#frequency ⇒ String
Required. The frequency unit of this recurring schedule.
Corresponds to the JSON property frequency
3615 3616 3617 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3615 def frequency @frequency end |
#last_execute_time ⇒ String
Output only. The time the last patch job ran successfully.
Corresponds to the JSON property lastExecuteTime
3620 3621 3622 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3620 def last_execute_time @last_execute_time end |
#monthly ⇒ Google::Apis::OsconfigV1::MonthlySchedule
Represents a monthly schedule. An example of a valid monthly schedule is "on
the third Tuesday of the month" or "on the 15th of the month".
Corresponds to the JSON property monthly
3626 3627 3628 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3626 def monthly @monthly end |
#next_execute_time ⇒ String
Output only. The time the next patch job is scheduled to run.
Corresponds to the JSON property nextExecuteTime
3631 3632 3633 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3631 def next_execute_time @next_execute_time end |
#start_time ⇒ String
Optional. The time that the recurring schedule becomes effective. Defaults to
create_time of the patch deployment.
Corresponds to the JSON property startTime
3637 3638 3639 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3637 def start_time @start_time end |
#time_of_day ⇒ Google::Apis::OsconfigV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property timeOfDay
3644 3645 3646 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3644 def time_of_day @time_of_day end |
#time_zone ⇒ Google::Apis::OsconfigV1::TimeZone
Represents a time zone from the IANA Time Zone Database.
Corresponds to the JSON property timeZone
3650 3651 3652 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3650 def time_zone @time_zone end |
#weekly ⇒ Google::Apis::OsconfigV1::WeeklySchedule
Represents a weekly schedule.
Corresponds to the JSON property weekly
3655 3656 3657 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3655 def weekly @weekly end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3662 3663 3664 3665 3666 3667 3668 3669 3670 3671 3672 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3662 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @frequency = args[:frequency] if args.key?(:frequency) @last_execute_time = args[:last_execute_time] if args.key?(:last_execute_time) @monthly = args[:monthly] if args.key?(:monthly) @next_execute_time = args[:next_execute_time] if args.key?(:next_execute_time) @start_time = args[:start_time] if args.key?(:start_time) @time_of_day = args[:time_of_day] if args.key?(:time_of_day) @time_zone = args[:time_zone] if args.key?(:time_zone) @weekly = args[:weekly] if args.key?(:weekly) end |