Class: Google::Apis::OsconfigV1::VulnerabilityReportVulnerabilityDetails
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1::VulnerabilityReportVulnerabilityDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb
Overview
Contains metadata information for the vulnerability. This information is collected from the upstream feed of the operating system.
Instance Attribute Summary collapse
-
#cve ⇒ String
The CVE of the vulnerability.
-
#cvss_v2_score ⇒ Float
The CVSS V2 score of this vulnerability.
-
#cvss_v3 ⇒ Google::Apis::OsconfigV1::CvsSv3
Common Vulnerability Scoring System version 3.
-
#description ⇒ String
The note or description describing the vulnerability from the distro.
-
#references ⇒ Array<Google::Apis::OsconfigV1::VulnerabilityReportVulnerabilityDetailsReference>
Corresponds to the references attached to the
VulnerabilityDetails. -
#severity ⇒ String
Assigned severity/impact ranking from the distro.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VulnerabilityReportVulnerabilityDetails
constructor
A new instance of VulnerabilityReportVulnerabilityDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VulnerabilityReportVulnerabilityDetails
Returns a new instance of VulnerabilityReportVulnerabilityDetails.
3996 3997 3998 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3996 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cve ⇒ String
The CVE of the vulnerability. CVE cannot be empty and the combination of
should be unique across vulnerabilities for a VM.
Corresponds to the JSON property cve
3967 3968 3969 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3967 def cve @cve end |
#cvss_v2_score ⇒ Float
The CVSS V2 score of this vulnerability. CVSS V2 score is on a scale of 0 - 10
where 0 indicates low severity and 10 indicates high severity.
Corresponds to the JSON property cvssV2Score
3973 3974 3975 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3973 def cvss_v2_score @cvss_v2_score end |
#cvss_v3 ⇒ Google::Apis::OsconfigV1::CvsSv3
Common Vulnerability Scoring System version 3. For details, see https://www.
first.org/cvss/specification-document
Corresponds to the JSON property cvssV3
3979 3980 3981 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3979 def cvss_v3 @cvss_v3 end |
#description ⇒ String
The note or description describing the vulnerability from the distro.
Corresponds to the JSON property description
3984 3985 3986 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3984 def description @description end |
#references ⇒ Array<Google::Apis::OsconfigV1::VulnerabilityReportVulnerabilityDetailsReference>
Corresponds to the references attached to the VulnerabilityDetails.
Corresponds to the JSON property references
3989 3990 3991 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3989 def references @references end |
#severity ⇒ String
Assigned severity/impact ranking from the distro.
Corresponds to the JSON property severity
3994 3995 3996 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 3994 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4001 4002 4003 4004 4005 4006 4007 4008 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 4001 def update!(**args) @cve = args[:cve] if args.key?(:cve) @cvss_v2_score = args[:cvss_v2_score] if args.key?(:cvss_v2_score) @cvss_v3 = args[:cvss_v3] if args.key?(:cvss_v3) @description = args[:description] if args.key?(:description) @references = args[:references] if args.key?(:references) @severity = args[:severity] if args.key?(:severity) end |