Class: Google::Apis::OsconfigV1::VulnerabilityReportVulnerabilityItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb

Overview

OS inventory item that is affected by a vulnerability or fixed as a result of a vulnerability.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VulnerabilityReportVulnerabilityItem

Returns a new instance of VulnerabilityReportVulnerabilityItem.



4070
4071
4072
# File 'lib/google/apis/osconfig_v1/classes.rb', line 4070

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#available_inventory_item_idString

Corresponds to the AVAILABLE_PACKAGE inventory item on the VM. If the vulnerability report was not updated after the VM inventory update, these values might not display in VM inventory. If there is no available fix, the field is empty. The inventory_item value specifies the latest SoftwarePackage available to the VM that fixes the vulnerability. Corresponds to the JSON property availableInventoryItemId

Returns:

  • (String)


4048
4049
4050
# File 'lib/google/apis/osconfig_v1/classes.rb', line 4048

def available_inventory_item_id
  @available_inventory_item_id
end

#fixed_cpe_uriString

The recommended CPE URI update that contains a fix for this vulnerability. Corresponds to the JSON property fixedCpeUri

Returns:

  • (String)


4054
4055
4056
# File 'lib/google/apis/osconfig_v1/classes.rb', line 4054

def fixed_cpe_uri
  @fixed_cpe_uri
end

#installed_inventory_item_idString

Corresponds to the INSTALLED_PACKAGE inventory item on the VM. This field displays the inventory items affected by this vulnerability. If the vulnerability report was not updated after the VM inventory update, these values might not display in VM inventory. For some operating systems, this field might be empty. Corresponds to the JSON property installedInventoryItemId

Returns:

  • (String)


4063
4064
4065
# File 'lib/google/apis/osconfig_v1/classes.rb', line 4063

def installed_inventory_item_id
  @installed_inventory_item_id
end

#upstream_fixString

The upstream OS patch, packages or KB that fixes the vulnerability. Corresponds to the JSON property upstreamFix

Returns:

  • (String)


4068
4069
4070
# File 'lib/google/apis/osconfig_v1/classes.rb', line 4068

def upstream_fix
  @upstream_fix
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4075
4076
4077
4078
4079
4080
# File 'lib/google/apis/osconfig_v1/classes.rb', line 4075

def update!(**args)
  @available_inventory_item_id = args[:available_inventory_item_id] if args.key?(:available_inventory_item_id)
  @fixed_cpe_uri = args[:fixed_cpe_uri] if args.key?(:fixed_cpe_uri)
  @installed_inventory_item_id = args[:installed_inventory_item_id] if args.key?(:installed_inventory_item_id)
  @upstream_fix = args[:upstream_fix] if args.key?(:upstream_fix)
end