Class: Google::Apis::OsconfigV1::WindowsUpdateSettings
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1::WindowsUpdateSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb
Overview
Windows patching is performed using the Windows Update Agent.
Instance Attribute Summary collapse
-
#classifications ⇒ Array<String>
Only apply updates of these windows update classifications.
-
#excludes ⇒ Array<String>
List of KBs to exclude from update.
-
#exclusive_patches ⇒ Array<String>
An exclusive list of kbs to be updated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WindowsUpdateSettings
constructor
A new instance of WindowsUpdateSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WindowsUpdateSettings
Returns a new instance of WindowsUpdateSettings.
4161 4162 4163 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 4161 def initialize(**args) update!(**args) end |
Instance Attribute Details
#classifications ⇒ Array<String>
Only apply updates of these windows update classifications. If empty, all
updates are applied.
Corresponds to the JSON property classifications
4148 4149 4150 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 4148 def classifications @classifications end |
#excludes ⇒ Array<String>
List of KBs to exclude from update.
Corresponds to the JSON property excludes
4153 4154 4155 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 4153 def excludes @excludes end |
#exclusive_patches ⇒ Array<String>
An exclusive list of kbs to be updated. These are the only patches that will
be updated. This field must not be used with other patch configurations.
Corresponds to the JSON property exclusivePatches
4159 4160 4161 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 4159 def exclusive_patches @exclusive_patches end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4166 4167 4168 4169 4170 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 4166 def update!(**args) @classifications = args[:classifications] if args.key?(:classifications) @excludes = args[:excludes] if args.key?(:excludes) @exclusive_patches = args[:exclusive_patches] if args.key?(:exclusive_patches) end |