Class: Google::Apis::OsconfigV1::YumSettings
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1::YumSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1/classes.rb,
lib/google/apis/osconfig_v1/representations.rb,
lib/google/apis/osconfig_v1/representations.rb
Overview
Yum patching is performed by executing yum update. Additional options can be
set to control how this is executed. Note that not all settings are supported
on all platforms.
Instance Attribute Summary collapse
-
#excludes ⇒ Array<String>
List of packages to exclude from update.
-
#exclusive_packages ⇒ Array<String>
An exclusive list of packages to be updated.
-
#minimal ⇒ Boolean
(also: #minimal?)
Will cause patch to run
yum update-minimalinstead. -
#security ⇒ Boolean
(also: #security?)
Adds the
--securityflag toyum update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ YumSettings
constructor
A new instance of YumSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ YumSettings
Returns a new instance of YumSettings.
4204 4205 4206 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 4204 def initialize(**args) update!(**args) end |
Instance Attribute Details
#excludes ⇒ Array<String>
List of packages to exclude from update. These packages are excluded by using
the yum --exclude flag.
Corresponds to the JSON property excludes
4183 4184 4185 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 4183 def excludes @excludes end |
#exclusive_packages ⇒ Array<String>
An exclusive list of packages to be updated. These are the only packages that
will be updated. If these packages are not installed, they will be ignored.
This field must not be specified with any other patch configuration fields.
Corresponds to the JSON property exclusivePackages
4190 4191 4192 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 4190 def exclusive_packages @exclusive_packages end |
#minimal ⇒ Boolean Also known as: minimal?
Will cause patch to run yum update-minimal instead.
Corresponds to the JSON property minimal
4195 4196 4197 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 4195 def minimal @minimal end |
#security ⇒ Boolean Also known as: security?
Adds the --security flag to yum update. Not supported on all platforms.
Corresponds to the JSON property security
4201 4202 4203 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 4201 def security @security end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4209 4210 4211 4212 4213 4214 |
# File 'lib/google/apis/osconfig_v1/classes.rb', line 4209 def update!(**args) @excludes = args[:excludes] if args.key?(:excludes) @exclusive_packages = args[:exclusive_packages] if args.key?(:exclusive_packages) @minimal = args[:minimal] if args.key?(:minimal) @security = args[:security] if args.key?(:security) end |